        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 20 <br>1,7,11,12,13,14,20,21,22,23,27,30,35,36,37,38,40,47,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 20 <strong>control</strong><br>0,2,3,4,5,6,8,9,15,18,28,29,31,34,41,42,43,44,46,48';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260528 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>10,16,17,19,24,25,26,32,33,39,45';}
}
